User

Struct User 

pub struct User {
    pub user_id: Option<String>,
    pub email: Option<String>,
    pub ip: Option<String>,
    pub user_agent: Option<String>,
    pub country: Option<String>,
    pub locale: Option<String>,
    pub app_version: Option<String>,
    pub custom: Option<HashMap<String, Value>>,
    pub private_attributes: Option<HashMap<String, Value>>,
    pub custom_ids: Option<HashMap<String, String>>,
    pub statsig_environment: Option<StatsigEnvironment>,
}

Fields

user_id: Option<String>email: Option<String>ip: Option<String>user_agent: Option<String>country: Option<String>locale: Option<String>app_version: Option<String>custom: Option<HashMap<String, Value>>private_attributes: Option<HashMap<String, Value>>custom_ids: Option<HashMap<String, String>>statsig_environment: Option<StatsigEnvironment>

Implementations

Source

impl User

Source

impl User

pub fn validate_user(&self) -> Result<()>

pub fn with_user_id(user_id: impl Into<String>) -> UserBuilder<SetUserId>

Creates a new user with just a user ID

This is a convenience method for the most common use case

pub fn get_primary_id(&self) -> Option<&str>

pub fn user_id(&self) -> Option<&str>

Get user ID (alias for userID for consistency)

pub fn hash_for_cache(&self) -> String

Generates a consistent hash for the user used in cache keys and batch grouping

This hash includes all user identifiers to ensure consistent cache behavior across different user representations with the same logical identity.